Simulators
==========

The built-in simulators in Piquasso.


.. toctree::
   :maxdepth: 3
   :caption: Simulators:
   :hidden:

   gaussian
   fock
   sampling


.. grid:: 3

   .. grid-item-card::  Gaussian simulator
      :link: gaussian
      :link-type: doc
      :class-title: cardclass

      Simulate Gaussian states, i.e., states characterized by first and second moments.

   .. grid-item-card::  Fock space-based simulators
      :link: fock
      :link-type: doc

      Simulate generic photonic states using its coefficients in the Fock basis.

   .. grid-item-card::  Boson Sampling simulator
      :link: sampling
      :link-type: doc

      Simulate Boson Sampling, a scheme using interferometers and terminal particle
      number detectors.
